@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: forms.py 11055 2018-05-14 09:46:32Z Lavender $
+# $Id: forms.py 11155 2018-07-08 13:33:33Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2018-05-14 17:46:32 +0800 (週一, 14 五月 2018) $
-# $Revision: 11055 $
+# $Date: 2018-07-08 22:33:33 +0900 (週日, 08 七月 2018) $
+# $Revision: 11155 $
 
 from django import forms
 
@@ -32,8 +32,11 @@ if hasattr(Product, 'tags'):
     tagList = [
         (0, '------'),
     ]
-    for tag in Tag.objects.all():
-        tagList.append((tag.id, tag.name))
+    try:
+        for tag in Tag.objects.all():
+            tagList.append((tag.id, tag.name))
+    except Exception as e:
+        pass
 
 class OscarFeaturedForm(forms.ModelForm):
     if hasTags:
